@@ -6,3 +6,6 @@
 
 /* Define to `int' if <sys/types.h> doesn't define.  */
 #undef ssize_t
+
+/* definition for Default Char Set */
+#undef FALLBACK_ENCODING
